### Constant
##### How to use!
from constant import final
<constant_name> = final.cons(<any_datatype>,<constant_name>)

To make constant you have to give same constant name on both the sides.
example : 
    pi = final.cons(3.14,"pi")
so, that it will work properly